@@ -1,5 +1,5 @@
 #
-# $Id: Info.pm,v 1.8 2005/03/01 09:48:30 dave Exp $
+# $Id: Info.pm 33 2007-04-01 15:28:04Z dave $
 #
 
 =head1 NAME
@@ -147,7 +147,7 @@ use Carp;
 
 use YAML 'LoadFile';
 
-our $VERSION = sprintf "%d.%02d", '$Revision: 1.8 $ ' =~ /(\d+)\.(\d+)/;
+our $VERSION = 1.09;
 
 =head1 METHODS
 
@@ -229,20 +229,13 @@ Changing and writing data.
 
 =head1 AUTHOR
 
-Dave Cross, E<lt>dave@dave.org.ukE<gt>
+Dave Cross, E<lt>dave@mag-sol.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2005 by Dave Cross
+Copyright 2003-2007 by Magnum Solutions Ltd. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
-#
-# $Log: Info.pm,v $
-# Revision 1.8  2005/03/01 09:48:30  dave
-# Improved test coverage
-#
-#
